@@ -19,7 +19,7 @@ retry_strategy = Retry(
     allowed_methods=frozenset({'DELETE', 'GET', 'HEAD', 'OPTIONS', 'POST', 'PUT', 'TRACE'})
 )
 adapter = HTTPAdapter(max_retries=retry_strategy)
-DEFAULT_TIMEOUT=5
+DEFAULT_TIMEOUT=20
 http = requests.Session()
 # set the raise_for_status flag to raise exceptions on http status codes other than 200
 http.hooks = {
@@ -227,7 +227,8 @@ def api2cmd_input(tool_group, api_inputs = {}, stage_id = None):
         'phbr': api2cmd_input_phbr,
         'mutgen': api2cmd_input_mutgen,
         'cluster': api2cmd_input_cluster,
-        'pepmatch': api2cmd_input_pepmatch
+        'pepmatch': api2cmd_input_pepmatch,
+        'bcell_structure': api2cmd_input_bcell_structure
     }
     
     print(f"generating command line inputs for {tool_group}")
@@ -407,6 +408,20 @@ def api2cmd_input_mhci(api_inputs = {}, stage_id = None):
 
     return cmd_input
 
+def api2cmd_input_bcell_structure(api_inputs = {}, stage_id = None):
+    """Given a dict of stage input_data OR a stage_id,
+    return the JSON necessary for the bcell_structure command line tool"""
+
+    # TODO: this will retrieve from the main server, but there
+    # should be a way to pull from any server
+    if stage_id != None:
+        api_inputs = NXGclient().get_stage_inputs(stage_id)
+    
+    # start with the input parameters
+    cmd_input = api_inputs['input_parameters']['data']
+
+    return cmd_input
+
 def cmd2api_output_mhci(cmd_output):
     """Given the aggregated output from the command line tool,
     update to the format needed by the API.
@@ -515,10 +530,17 @@ def cmd2api_output_mhci(cmd_output):
                 field_name = key
             if field_name in unique_vals:
                 value_limits['unique_values'] = unique_vals[field_name]
+            # check lowercase version of the field name if field_name not found
+            elif field_name.lower() in unique_vals:
+                value_limits['unique_values'] = unique_vals[field_name.lower()]
 
             if field_name in field_ranges:
                 value_limits['min'] = float(field_ranges[field_name]['min'])
                 value_limits['max'] = float(field_ranges[field_name]['max'])
+            # check lowercase version of the field name
+            elif field_name.lower() in field_ranges:
+                value_limits['min'] = float(field_ranges[field_name.lower()]['min'])
+                value_limits['max'] = float(field_ranges[field_name.lower()]['max'])
             
             if value_limits:
                 f['value_limits'] = value_limits
