@@ -65,7 +65,7 @@ BASE_COLUMN_MAP = {
         "type": "int",
         "source": "core",
         "sort_order": 1,
-        "row_sort_priority": None,
+        "row_sort_priority": 8,
         "default_order": None,
         "description": "Peptide sequence start within the context of the input sequence",
         "hidden": False,
@@ -76,7 +76,7 @@ BASE_COLUMN_MAP = {
         "type": "int",
         "source": "core",
         "sort_order": 2,
-        "row_sort_priority": None,
+        "row_sort_priority": 9,
         "default_order": None,
         "description": "Peptide sequence end within the context of the input sequence",
         "hidden": False,
@@ -103,6 +103,30 @@ BASE_COLUMN_MAP = {
         "description": "Serial number of the peptide among all peptides",
         "hidden": True,
     },
+    # for PHBR
+    # names were changed to core.mutant_peptide, and core.reference_peptide to core.ref_peptide
+    "core.mutant_peptide": {
+        "name": "mutant_peptide",
+        "display_name": "mutant peptide",
+        "type": "text",
+        "source": "core",
+        "sort_order": 3,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "mutant peptide sequence",
+        "hidden": False,
+    },
+    "core.reference_peptide": {
+        "name": "reference_peptide",
+        "display_name": "reference peptide",
+        "type": "text",
+        "source": "core",
+        "sort_order": 4,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Reference peptide sequence",
+        "hidden": False,
+    },
     # binding - overall
     # these parameters will be from source 'binding', not tied to a specific method
     # there will be 1 instance of these columns regardless of how many methods
@@ -159,7 +183,7 @@ BASE_COLUMN_MAP = {
     },
     "binding.ic50": {
         "name": "ic50",
-        "display_name": "IC50",
+        "display_name": "ic50",
         "type": "float",
         "source": "binding/elution",
         "sort_order": 1,
@@ -255,10 +279,60 @@ BASE_COLUMN_MAP = {
     },
     # mhcii are with mhci
 
+    # mhciinp
+    # these 4 columns are from the mhciinp method only
+    #binding.mhciinp.n_motif 	binding.mhciinp.c_motif 	binding.mhciinp.cleavage_probability_score 	binding.mhciinp.cleavage_probability_percentile_rank 
+    "processing.mhciinp.n_motif": {
+        "name": "n_motif",
+        "display_name": "mhcii-np n motif",
+        "type": "text",
+        "source": "processing.mhciinp",
+        "sort_order": 3,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "the N-terminus considered for calculating the cleavage probability score",
+        "hidden": False,
+    },
+    "processing.mhciinp.c_motif": {
+        "name": "c_motif",
+        "display_name": "mhcii-np c motif",
+        "type": "text",
+        "source": "processing.mhciinp",
+        "sort_order": 3,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "the C-terminus considered for calculating the cleavage probability score",
+        "hidden": False,
+    },
+    "processing.mhciinp.cleavage_probability_score": {
+        "name": "cleavage_probability_score",
+        "display_name": "mhcii-np cleavage probability score",
+        "type": "float",
+        "source": "processing.mhciinp",
+        "sort_order": 0,
+        "row_sort_priority": 3,
+        "default_order": "descending",
+        "number_of_digits": 4,
+        "description": "The cleavage probability score indicates the probability of the peptide being an MHC II ligand based on three components: (1) the peptide length (2) the N-terminus cleavage motif and (3) the C-terminus cleavage motif. The higher the numerical value of cleavage probability score, the better is the chance of the peptide being a ligand.",
+        "hidden": False,
+    },
+    "processing.mhciinp.cleavage_probability_percentile_rank": {
+        "name": "cleavage_probability_percentile_rank",
+        "display_name": "mhcii-np cleavage probability percentile rank",
+        "type": "float",
+        "source": "processing.mhciinp",
+        "sort_order": 1,
+        "row_sort_priority": 3,
+        "default_order": "ascending",
+        "number_of_digits": None,
+        "description": "The predicted cleavage probability score in terms of percentile ranks per the corresponding source protein. The lower the numerical value of the percentile score, the better is the chance of the peptide being a ligand.",
+        "hidden": False,
+    },
+
     # cd4episcore
     "immunogenicity.cd4episcore.core": {
         "name": "cd4episcore_core",
-        "display_name": "CD4episcore core",
+        "display_name": "cd4episcore core",
         "type": "text",
         "source": "immunogenicity.cd4episcore",
         "sort_order": 3,
@@ -281,7 +355,7 @@ BASE_COLUMN_MAP = {
     },
     "immunogenicity.cd4episcore.combined_score": {
         "name": "combined_score",
-        "display_name": "immunogenicity Combined Score",
+        "display_name": "immunogenicity combined score",
         "type": "float",
         "source": "immunogenicity.cd4episcore",
         "sort_order": 0,
@@ -447,7 +521,7 @@ BASE_COLUMN_MAP = {
     # netchop
     "processing.netchop.prediction_score": {
         "name": "prediction_score",
-        "display_name": "NetChop Predictions score",
+        "display_name": "netchop predictions score",
         "type": "float",
         "source": "processing.netchop",
         "sort_order": 2,
@@ -482,7 +556,7 @@ BASE_COLUMN_MAP = {
     # netctl
     "processing.netctl.supertype": {
         "name": "supertype",
-        "display_name": "NetCTL Supertype",
+        "display_name": "netctl supertype",
         "type": "text",
         "source": "processing.netctl",
         "sort_order": 3,
@@ -493,7 +567,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctl.c_terminal_cleavage_affinity": {
         "name": "c_terminal_cleavage_affinity",
-        "display_name": "NetCTL c terminal cleavage affinity",
+        "display_name": "netctl c terminal cleavage affinity",
         "type": "float",
         "source": "processing.netctl",
         "sort_order": 0,
@@ -506,7 +580,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctl.tap_transport_efficiency": {
         "name": "tap_transport_efficiency",
-        "display_name": "NetCTL TAP transport efficiency",
+        "display_name": "netctl tap transport efficiency",
         "type": "float",
         "source": "processing.netctl",
         "sort_order": 1,
@@ -518,7 +592,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctl.predictions_score": {
         "name": "predictions_score",
-        "display_name": "NetCTL Prediction score",
+        "display_name": "netctl prediction score",
         "type": "float",
         "source": "processing.netctl",
         "sort_order": 2,
@@ -530,7 +604,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctl.predicted_mhc_binding_affinity": {
         "name": "predicted_mhc_binding_affinity",
-        "display_name": "NetCTL Predicted MHC binding affinity",
+        "display_name": "netctl predicted mhc binding affinity",
         "type": "float",
         "source": "processing.netctl",
         "sort_order": 4,
@@ -542,7 +616,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctl.rescale_binding_affinity": {
         "name": "rescale_binding_affinity",
-        "display_name": "NetCTL Rescaled binding affinity",
+        "display_name": "netctl rescaled binding affinity",
         "type": "float",
         "source": "processing.netctl",
         "sort_order": 3,
@@ -555,7 +629,7 @@ BASE_COLUMN_MAP = {
     # netctlpan
     "processing.netctlpan.cleavage_prediction_score": {
         "name": "cleavage_prediction_score",
-        "display_name": "NetCTLpan cleavage prediction score",
+        "display_name": "netctlpan cleavage prediction score",
         "type": "float",
         "source": "processing.netctlpan",
         "sort_order": 0,
@@ -568,7 +642,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctlpan.tap_prediction_score": {
         "name": "tap_prediction_score",
-        "display_name": "NetCTLpan tap score",
+        "display_name": "netctlpan tap score",
         "type": "float",
         "source": "processing.netctlpan",
         "sort_order": 1,
@@ -580,7 +654,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctlpan.mhc_prediction": {
         "name": "mhc_prediction",
-        "display_name": "NetCTLpan MHC score",
+        "display_name": "netctlpan mhc score",
         "type": "float",
         "source": "processing.netctlpan",
         "sort_order": 2,
@@ -592,7 +666,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctlpan.combined_prediction_score": {
         "name": "combined_prediction_score",
-        "display_name": "NetCTLpan combined score",
+        "display_name": "netctlpan combined score",
         "type": "float",
         "source": "processing.netctlpan",
         "sort_order": 4,
@@ -604,7 +678,7 @@ BASE_COLUMN_MAP = {
     },
     "processing.netctlpan.percentile_rank": {
         "name": "percentile_rank",
-        "display_name": "NetCTLpan percentile rank",
+        "display_name": "netctlpan percentile rank",
         "type": "float",
         "source": "processing.netctlpan",
         "sort_order": 3,
@@ -617,7 +691,7 @@ BASE_COLUMN_MAP = {
     # mhcnp
     "processing.mhcnp.score": {
         "name": "score",
-        "display_name": "MHC-NP Prob score",
+        "display_name": "mhc-np prob score",
         "type": "float",
         "source": "processing.mhcnp",
         "sort_order": 0,
@@ -689,10 +763,20 @@ BASE_COLUMN_MAP = {
         "description": "Sum of the MHC and Processing scores",
         "hidden": False,
     },
+    # phbr
+    "phbr.#a":    { "name": "#a", "display_name":"number of HLA-A alleles", "type": "int", "source": "phbr", "sort_order": 3, "row_sort_priority": None, "default_order": None, "description": "number of HLA-A alleles.", "hidden": True, "display_length": 5 },
+    "phbr.#b":    { "name": "#b", "display_name":"number of HLA-B alleles", "type": "int", "source": "phbr", "sort_order": 3, "row_sort_priority": None, "default_order": None, "description": "number of HLA-B alleles.", "hidden": True, "display_length": 5 },
+    "phbr.#c":    { "name": "#c", "display_name":"number of HLA-C alleles", "type": "int", "source": "phbr", "sort_order": 3, "row_sort_priority": None, "default_order": None, "description": "number of HLA-C alleles.", "hidden": True, "display_length": 5 },
+    "phbr.phbr":  { "name": "phbr", "display_name":"PHBR score", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class I or class II input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
+    "phbr.phbr-i":  { "name": "phbr-i", "display_name":"PHBR-I", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class I  input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
+    "phbr.phbr-ii":  { "name": "phbr-ii", "display_name":"PHBR-II", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class II input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
+    "phbr.phbr-mhci":  { "name": "phbr-i", "display_name":"PHBR-I", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class I  input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
+    "phbr.phbr-mhcii":  { "name": "phbr-ii", "display_name":"PHBR-II", "type": "float", "source": "phbr", "sort_order": 1, "row_sort_priority": 0, "default_order": 'descending', "number_of_digits": 4, "description": "Harmonic mean of the lowest (best) ranked peptides across all class II input alleles.  Peptides that do not overlap the mutation position(s) are removed from consideration.", "hidden": False },
+
     # pepmatch
     "pepmatch.peptide": {
         "name": "peptide",
-        "display_name": "Input Sequence",
+        "display_name": "input sequence",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 3,
@@ -703,7 +787,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.matched_sequence": {
         "name": "matched_sequence",
-        "display_name": "Matched Sequence",
+        "display_name": "matched sequence",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 3,
@@ -714,7 +798,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.taxon_id": {
         "name": "taxon_id",
-        "display_name": "Taxon ID",
+        "display_name": "taxon id",
         "type": "int",
         "source": "pepmatch",
         "sort_order": 4,
@@ -725,7 +809,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.species": {
         "name": "species",
-        "display_name": "Species",
+        "display_name": "species",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 4,
@@ -736,7 +820,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.gene": {
         "name": "gene",
-        "display_name": "Gene",
+        "display_name": "gene",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 4,
@@ -747,7 +831,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.protein_id": {
         "name": "protein_id",
-        "display_name": "Protein ID",
+        "display_name": "protein id",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 1,
@@ -758,7 +842,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.protein_name": {
         "name": "protein_name",
-        "display_name": "Protein Name",
+        "display_name": "protein name",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 1,
@@ -770,7 +854,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.mismatches": {
         "name": "mismatches",
-        "display_name": "Mismatches",
+        "display_name": "mismatches",
         "type": "int",
         "source": "pepmatch",
         "sort_order": 1,
@@ -781,7 +865,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.mutated_positions": {
         "name": "mutated_positions",
-        "display_name": "Mutated Positions",
+        "display_name": "mutated positions",
         "type": "text",
         "source": "pepmatch",
         "sort_order": 1,
@@ -792,7 +876,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.index_start": {
         "name": "index_start",
-        "display_name": "Index start",
+        "display_name": "index start",
         "type": "int",
         "source": "pepmatch",
         "sort_order": 1,
@@ -803,7 +887,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.index_end": {
         "name": "index_end",
-        "display_name": "Index end",
+        "display_name": "index end",
         "type": "int",
         "source": "pepmatch",
         "sort_order": 2,
@@ -814,7 +898,7 @@ BASE_COLUMN_MAP = {
     },
     "pepmatch.protein_existence_level": {
         "name": "protein_existence_level",
-        "display_name": "Protein Existence Level",
+        "display_name": "protein existence level",
         "type": "int",
         "source": "pepmatch",
         "sort_order": 5,
@@ -905,7 +989,7 @@ BASE_COLUMN_MAP = {
     },
     "mutgen.gene_id": {
         "name": "gene_id",
-        "display_name": "Ensembl gene accession",
+        "display_name": "ensembl gene accession",
         "type": "text",
         "source": "mutgen",
         "sort_order": 1,
@@ -955,7 +1039,7 @@ BASE_COLUMN_MAP = {
         "sort_order": 3,
         "row_sort_priority": None,
         "default_order": None,
-        "description": "list of reference-mutant peptide pairs derived from this SNP, along with peptide mutation position.  Corresopnding peptides will be found in the peptide output tables.",
+        "description": "list of reference-mutant peptide pairs derived from this variant, along with peptide mutation position.  Corresopnding peptides will be found in the peptide output tables.",
         "hidden": False,
     },
     "mutgen.peptide_warning": {
@@ -1004,7 +1088,7 @@ BASE_COLUMN_MAP = {
     },
     "mutgen.transcript_id": {
         "name": "transcript_id",
-        "display_name": "Ensembl transcript accession",
+        "display_name": "ensembl transcript accession",
         "type": "text",
         "source": "mutgen",
         "sort_order": 3,
@@ -1149,7 +1233,7 @@ BASE_COLUMN_MAP = {
     # cluster
     "cluster.cluster_number": {
         "name": "cluster_number",
-        "display_name": "Cluster.Sub-Cluster Number",
+        "display_name": "cluster.sub-cluster number",
         "type": "text",
         "source": "cluster",
         "sort_order": 1,
@@ -1160,7 +1244,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.peptide_number": {
         "name": "peptide_number",
-        "display_name": "Peptide Number",
+        "display_name": "peptide number",
         "type": "text",
         "source": "cluster",
         "sort_order": 2,
@@ -1171,7 +1255,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.alignment": {
         "name": "alignment",
-        "display_name": "Alignment",
+        "display_name": "alignment",
         "type": "text",
         "source": "cluster",
         "sort_order": 3,
@@ -1182,7 +1266,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.position": {
         "name": "position",
-        "display_name": "Position",
+        "display_name": "position",
         "type": "text",
         "source": "cluster",
         "sort_order": 4,
@@ -1193,7 +1277,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.sequence_number": {
         "name": "sequence_number",
-        "display_name": "Input seq id",
+        "display_name": "input seq id",
         "type": "text",
         "source": "cluster",
         "sort_order": 5,
@@ -1204,7 +1288,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.peptide": {
         "name": "peptide",
-        "display_name": "Peptide",
+        "display_name": "peptide",
         "type": "text",
         "source": "cluster",
         "sort_order": 6,
@@ -1215,7 +1299,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.cluster_consensus": {
         "name": "cluster_consensus",
-        "display_name": "Cluster Consensus",
+        "display_name": "cluster consensus",
         "type": "text",
         "source": "cluster",
         "sort_order": 7,
@@ -1226,7 +1310,7 @@ BASE_COLUMN_MAP = {
     },
     "cluster.clique_number": {
         "name": "clique_number",
-        "display_name": "Cliques Number",
+        "display_name": "cliques number",
         "type": "int",
         "source": "cluster",
         "sort_order": 1,
@@ -1238,7 +1322,7 @@ BASE_COLUMN_MAP = {
     # allele_distances_table
     "allele_distances.input_allele": {
         "name": "input_allele",
-        "display_name": "Input Allele",
+        "display_name": "input allele",
         "type": "text",
         "source": "allele_distances",
         "sort_order": 5,
@@ -1249,7 +1333,7 @@ BASE_COLUMN_MAP = {
     },
     "allele_distances.closest_allele": {
         "name": "closest_allele",
-        "display_name": "Closest Allele",
+        "display_name": "closest allele",
         "type": "text",
         "source": "allele_distances",
         "sort_order": 5,
@@ -1260,7 +1344,7 @@ BASE_COLUMN_MAP = {
     },
     "allele_distances.allele_distances": {
         "name": "allele_distances",
-        "display_name": "Distance",
+        "display_name": "distance",
         "type": "int",
         "source": "allele_distances",
         "sort_order": 6,
@@ -1269,6 +1353,145 @@ BASE_COLUMN_MAP = {
         "description": " Alleles with lower distances to the training set will have more accurate predictions. A distance of 0 indicates a perfect match between alleles and values at or below 0.1 is considered acceptable for generating accurate predictions.",
         "hidden": False,
     },
+    # bcell_structure - linear epitopes
+    "core.pdb_chain": {
+        "name": "core.pdb_chain",
+        "display_name": "chain",
+        "type": "text",
+        "source": "core",
+        "sort_order": None,
+        "row_sort_priority": 0,
+        "default_order": None,
+        "description": "Chain identifier of the protein structure",
+        "hidden": False,
+    },
+    "core.peptide_source": {
+        "name": "core.peptide_source",
+        "display_name": "peptide source",
+        "type": "text",
+        "source": "core",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Source method of the peptide (ellipro or discotope)",
+        "hidden": False,
+    },
+    "core.number_of_residues": {
+        "name": "core.number_of_residues",
+        "display_name": "number of residues",
+        "type": "int",
+        "source": "core",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Number of residues in the epitope",
+        "hidden": False,
+    },
+    "discotope.score": {
+        "name": "discotope.score",
+        "display_name": "discotope score",
+        "type": "float",
+        "source": "discotope",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "DiscoTope-3.0 predicted epitope score",
+        "hidden": False,
+        "number_of_digits": 6,
+    },
+    "discotope.calibrated_score": {
+        "name": "discotope.calibrated_score",
+        "display_name": "discotope calibrated score",
+        "type": "float",
+        "source": "discotope",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Calibrated DiscoTope-3.0 score, normalized for protein length and surface scores",
+        "hidden": False,
+        "number_of_digits": 6,
+    },
+    "discotope.plddts": {
+        "name": "discotope.plddts",
+        "display_name": "pLDDTs",
+        "type": "int",
+        "source": "discotope",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "AlphaFold pLDDT score (set to 100 for non-AlphaFold structures)",
+        "hidden": False,
+    },
+    "ellipro.score": {
+        "name": "ellipro.score",
+        "display_name": "ellipro score",
+        "type": "float",
+        "source": "ellipro",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "ElliPro predicted epitope score",
+        "hidden": False,
+        "number_of_digits": 3,
+    },
+    # bcell_structure - discontinuous epitopes
+    "core.residues": {
+        "name": "core.residues",
+        "display_name": "residues",
+        "type": "text",
+        "source": "core",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "List of residues forming the discontinuous epitope",
+        "hidden": False,
+    },
+    # bcell_structure - residue table
+    "core.res_id": {
+        "name": "core.res_id",
+        "display_name": "residue id",
+        "type": "int",
+        "source": "core",
+        "sort_order": None,
+        "row_sort_priority": 1,
+        "default_order": None,
+        "description": "Residue position in the protein sequence",
+        "hidden": False,
+    },
+    "core.residue": {
+        "name": "core.residue",
+        "display_name": "residue",
+        "type": "text",
+        "source": "core",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Single letter amino acid code",
+        "hidden": False,
+    },
+    "discotope.epitope": {
+        "name": "discotope.epitope",
+        "display_name": "epitope",
+        "type": "text",
+        "source": "discotope",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Predicted epitope column (based on chosen threshold). 'E' means epitope, '.' means not epitope.",
+        "hidden": False,
+    },
+    "discotope.rsa": {
+        "name": "discotope.rsa",
+        "display_name": "RSA",
+        "type": "float",
+        "source": "discotope",
+        "sort_order": None,
+        "row_sort_priority": None,
+        "default_order": None,
+        "description": "Relative surface accessibility (Shrake-Rupley, normalized using Sander scale)",
+        "hidden": False,
+        "number_of_digits": 5,
+    },
 }
 
 # define the binding methods
@@ -1303,9 +1526,12 @@ binding_methods += [
     "sturniolo",
 ]
 
-# define the binding summary columns that do not need to be copied
-# into each method
-binding_summary_fields = ["binding.consensus_percentile", "binding.consensus_percentile_rank", "binding.consensus_adjusted_percentile"]
+# define the binding summary columns that do not need to be copied into each method
+# mhciinp has its unique column names so those are added here too
+binding_summary_fields = [
+    "binding.consensus_percentile", "binding.consensus_percentile_rank", "binding.consensus_adjusted_percentile",
+    "processing.mhciinp.n_motif", "processing.mhciinp.c_motif","processing.mhciinp.cleavage_probability_score", "processing.mhciinp.cleavage_probability_percentile_rank",
+]
 
 peptide_variant_comparison_suffixes = ["peptideA", "peptideB", "peptideA_minusB", "peptideB_minusA"]
 
