@@ -70,6 +70,12 @@ all_settings = {
                 'mem_mb': 2000,
                 'modules': 'python/3.11.3',
                 'virtualenv': '/apps/python-virtualenvs/phbr'
+            },
+            'bcell_structure': {
+                'cmdline_path': '/apps/iedbtools/ng_bcell_structure/src/run_bcell_structure_based.py',
+                'mem_mb': 8000,
+                'modules': 'python/3.9.23',
+                'virtualenv': '/apps/python-virtualenvs/nxg-tools'
             }
         }
     },
@@ -138,6 +144,12 @@ all_settings = {
                 'mem_mb': 2000,
                 'modules': 'python/3.11.3',
                 'virtualenv': '/apps/python-virtualenvs/phbr'
+            },
+            'bcell_structure': {
+                'cmdline_path': '/apps/iedbtools/ng_bcell_structure/src/run_bcell_structure_based.py',
+                'mem_mb': 8000,
+                'modules': 'python/3.9.23',
+                'virtualenv': '/apps/python-virtualenvs/bcell_structure'
             }
         }
     }
