@@ -143,7 +143,7 @@ def merge_peptidea_peptideb_result(peptidea_result_path, peptideb_result_path, a
     logging.debug(final_peptide_table.to_csv())
 
     for column_a in [c for c in final_peptide_table.loc[:, final_peptide_table.dtypes == np.float64].columns if c.endswith('-peptideA')]:
-        logging.debug(column_a)
+        logging.debug(f"column_a: {column_a}")
         logging.debug(column_a.replace('-peptideA', '-peptideB') in final_peptide_table.columns)
         logging.debug(column_a.replace('-peptideA', '-peptideB'))
         column_b = column_a.replace('-peptideA', '-peptideB')
