@@ -126,7 +126,7 @@ def run_icerfire(params, output_prefix, output_format='json', assume_valid_flag=
     peptides_list = [peptides.split(',') for peptides in peptide_pair_dictkeys]
     peptides_list = [peptide for peptide in peptides_list if 8 <= len(peptide[0]) <= 14 and 8 <= len(peptide[1]) <= 14]
     if not peptides_list:
-        raise ValueError("No valid peptides found in input_sequence_text. Peptides must be between 8 and 14 amino acids long.")
+        raise ValueError("No valid peptides found in input_sequence_text. Peptides must be between 8 and 14 amino acids long for icerfire.")
     input_sequence_text = '\n'.join([','.join(peptide) for peptide in peptides_list])
     params['input_sequence_text'] = input_sequence_text
 
