@@ -34,6 +34,10 @@ if not TC1_EXECUTABLE_PATH:
     print('Path to the TC1 execuatble must be set.  See the README for details on rerunning the configure script')
     sys.exit(1)
 
+TC2_EXECUTABLE_PATH = os.environ.get('TC2_EXECUTABLE_PATH')
+if not TC2_EXECUTABLE_PATH:
+    from path_config import TC2_EXECUTABLE_PATH
+
 def generate_random_str(length):
     return ''.join(random.sample(string.digits+string.ascii_letters, length))
 
@@ -56,35 +60,73 @@ def split_peptidea_peptideb_peptides(input_sequence_text):
     peptides_list = [peptides.split(',') for peptides in peptide_pair_dictkeys]
     return list(zip(*peptides_list))
 
-def split_predictors(predictors):
+def split_predictors(predictors, mode='tc1'):
     icerfire_predictors = []
-    other_predictors =  []
+    mhci_predictors =  []
+    mhcii_predictors = []
+    other_predictors = []
     for p in predictors:
         if p.get('method','') == 'icerfire':
             icerfire_predictors.append(p)
+        elif p.get('tools_group','') == 'mhcii':
+            mhcii_predictors.append(p)
+        elif p.get('tools_group','') == 'mhci':
+            mhci_predictors.append(p)
         else:
             other_predictors.append(p)
-    return icerfire_predictors, other_predictors    
+    # TODO: check if mhci and mhcii predictors are valid, and if not, raise an error
+    if mode == 'tc1':
+        # if mode is tc1, we only use mhci predictors
+        mhci_predictors = mhci_predictors + other_predictors
+        if not mhci_predictors + icerfire_predictors:
+            raise ValueError('No mhci predictors found in the input data for tc1 mode')
+        if mhcii_predictors:
+            print('Warning: mhcii predictors are ignored in tc1 mode, only mhci predictors are used')
+            mhcii_predictors = []
+    elif mode == 'tc2':
+        # if mode is tc2, we only use mhcii predictors
+        mhcii_predictors = mhcii_predictors + other_predictors
+        if not mhcii_predictors:
+            raise ValueError('No mhcii predictors found in the input data for tc2 mode')
+        if mhci_predictors or icerfire_predictors:
+            print('Warning: mhci and icerfire predictors are ignored in tc2 mode, only mhcii predictors are used')
+            mhci_predictors = []
+            icerfire_predictors = []
+
+    return icerfire_predictors, mhci_predictors, mhcii_predictors    
 
 
-def get_peptide_list_with_sequencenumber(input_sequence_text):
+def get_peptide_list_with_sequencenumber(input_sequence_text, has_icerfire=False, mhci_predictors=None, mhcii_predictors=None):
     table_data = []
     peptide_pair_set = set()
     sequence_list = split_peptidea_peptideb_peptides(input_sequence_text)
     input_sequence_rows = list(zip(*sequence_list))
     seq_num = 1
+    # 8-14 for mhci and 11-30 for mhcii
+    if has_icerfire or mhci_predictors:
+        min_length = 8
+        max_length = 14
+    elif mhcii_predictors:
+        min_length = 11
+        max_length = 30
     for peptide_pair in zip(*sequence_list[:2]):
         if peptide_pair not in peptide_pair_set:
             peptide_pair_set.add(peptide_pair)
             peptidea, peptideb = peptide_pair
-            # remove peptides longer than 14 or shorter than 8
-            if len(peptidea) < 8 or len(peptideb) < 8 or len(peptidea) > 14 or len(peptideb) > 14:
-                print(f"Warning: exclude peptide pair {peptidea} and {peptideb} from prediction which is not in the range of 8-14")
+            # remove peptides longer than 14 or shorter than 8 for mhci, or longer than 30 or shorter than 11 for mhcii
+            if len(peptidea) < min_length or len(peptideb) < min_length or len(peptidea) > max_length or len(peptideb) > max_length:
+                print(f"Warning: exclude peptide pair {peptidea} and {peptideb} from prediction which is not in the range of {min_length}-{max_length}")
             else:
                 table_data.append((seq_num,peptidea, peptideb))
                 seq_num += 1
-    # remove crosponding rows from input_sequence_rows as well if peptides longer than 14 or shorter than 8
-    input_sequence_rows = [row for row in input_sequence_rows if len(row[0]) >= 8 and len(row[1]) >= 8 and len(row[0]) <= 14 and len(row[1]) <= 14]
+    # remove crosponding rows from input_sequence_rows as well if peptides longer than 14 or shorter than 8 for mhci, or longer than 30 or shorter than 11 for mhcii
+    input_sequence_rows = [row for row in input_sequence_rows if len(row[0]) >= min_length and len(row[1]) >= min_length and len(row[0]) <= max_length and len(row[1]) <= max_length]
+    '''
+    e.g. input_sequence_rows:
+    [('FLYNPLTRV', 'FLYNLL'), ('MLGERLFPL', 'MLGEQLFPL'), ('FLDEFMEAV', 'FLDEFMEGV'), ('VVLSWAPPV', 'VVMSWAPPV'), ('LLLDDSLVSI', 'LLLDDLLVSI'), ('GSFGDIYLA', 'GLFGDIYLA'), ('ALYGSVPVL', 'ALYGFVPVL'), ('ILTGLNYEA', 'ILTGLNYEV'), ('SLADEAEVHL', 'SLADEAEVYL'), ('CQWGRLWQL', 'CMWGRLWQL')]
+    table_data:
+    [(2, 'MLGERLFPL', 'MLGEQLFPL'), (3, 'FLDEFMEAV', 'FLDEFMEGV'), (4, 'VVLSWAPPV', 'VVMSWAPPV'), (5, 'LLLDDSLVSI', 'LLLDDLLVSI'), (6, 'GSFGDIYLA', 'GLFGDIYLA'), (7, 'ALYGSVPVL', 'ALYGFVPVL'), (8, 'ILTGLNYEA', 'ILTGLNYEV'), (9, 'SLADEAEVHL', 'SLADEAEVYL'), (10, 'CQWGRLWQL', 'CMWGRLWQL')]
+    '''
     table_columns = [
         "core.sequence_number",
         "core.peptide-peptideA",
@@ -125,15 +167,23 @@ def split_sequences(json_filename, parameters_output_dir=None, split_inputs_dir=
         input_data = json.load(r_file)
     has_icerfire = False
     has_others = False
-    icerfire_predictors, other_predictors = split_predictors(input_data['predictors'])
+    mode = input_data.get('mode', 'tc1')
+    if mode not in ['tc1', 'tc2']:
+        raise ValueError('mode must be either tc1 or tc2, got %s' % mode)
+    icerfire_predictors, mhci_predictors, mhcii_predictors = split_predictors(input_data['predictors'], mode=mode)
     if icerfire_predictors:
         has_icerfire = True
         icerfire_input_data = input_data.copy()
         icerfire_input_data['predictors'] = icerfire_predictors
-    if other_predictors:
+    if mhci_predictors or mhcii_predictors:
         has_others = True
         other_input_data = input_data.copy()
-        other_input_data['predictors'] = other_predictors
+        # TODO: now it's either mhci or mhcii, but we can have both in the future
+        #other_input_data['predictors'] = mhci_predictors + mhcii_predictors
+        if mhci_predictors:
+            other_input_data['predictors'] = mhci_predictors
+        elif mhcii_predictors:
+            other_input_data['predictors'] = mhcii_predictors
         input_data = other_input_data
     # recreate the directory
     if os.path.exists(parameters_output_dir):
@@ -159,6 +209,7 @@ def split_sequences(json_filename, parameters_output_dir=None, split_inputs_dir=
     job_descriptions_path = os.path.abspath(os.path.join(base_dir, 'job_descriptions.json'))
     #sequence_peptide_index_path = os.path.abspath(os.path.join(result_output_dir, 'peptides_index.json'))
     mhci_predict_executable_path = TC1_EXECUTABLE_PATH
+    mhcii_predict_executable_path = TC2_EXECUTABLE_PATH
     pvc_executable_path = os.path.abspath(os.path.join(os.path.dirname(__file__), 'run_pvc.py'))
     sequence_peptide_index_path = os.path.abspath(os.path.join(result_output_dir, 'sequence_peptide_index.json'))
 
@@ -186,9 +237,17 @@ def split_sequences(json_filename, parameters_output_dir=None, split_inputs_dir=
         raise ValueError('input_sequence_text must be provided')
     # get unique peptides pair with seq # with column names:  "sequence_number", "peptide-peptideA","peptide-peptideB",
     # it also updates input_sequence_text with iedblabel for allele and remove duplicates rows
-    sequence_peptide_index, input_sequence_text = get_peptide_list_with_sequencenumber(input_sequence_text)
+    # remove peptides longer than 14 or shorter than 8 for mhci, or longer than 30 or shorter than 11 for mhcii
+    sequence_peptide_index, input_sequence_text = get_peptide_list_with_sequencenumber(input_sequence_text, has_icerfire, mhci_predictors, mhcii_predictors)
     save_json(sequence_peptide_index, sequence_peptide_index_path)
-    if other_predictors:
+    # either mhci_predictors or mhcii_predictors for now
+    # TODO: change it if we want both mhci and mhcii in one prediction being supported
+    if mhci_predictors or (mhcii_predictors and not has_icerfire):
+        if mhci_predictors:
+            executable_path = mhci_predict_executable_path
+        elif mhcii_predictors:
+            executable_path = mhcii_predict_executable_path
+
         # create dir for peptidea and peptideb jobs
         peptidea_path = os.path.abspath(os.path.join(parameters_output_dir, 'peptidea'))
         peptideb_path = os.path.abspath(os.path.join(parameters_output_dir, 'peptideb'))
@@ -197,7 +256,11 @@ def split_sequences(json_filename, parameters_output_dir=None, split_inputs_dir=
 
         output_data = []
         peptide_file_path_length_pairs = []
+        if not input_sequence_text:
+            raise ValueError('input_sequence_text must contain at least one row with peptides')
         peptidea_peptideb_peptides = split_peptidea_peptideb_peptides(input_sequence_text)
+        if len(peptidea_peptideb_peptides) < 2:
+            raise ValueError('input_sequence_text must contain at least two columns with peptides')
         peptidea_peptide_list, peptideb_peptide_list = peptidea_peptideb_peptides[:2]
         if len(peptidea_peptideb_peptides) >= 3 and peptidea_peptideb_peptides[2]:
             av = AlleleValidator()
@@ -212,10 +275,10 @@ def split_sequences(json_filename, parameters_output_dir=None, split_inputs_dir=
         input_data['peptide_file_path'] = peptideb_peptides_path
         peptideb_input_path = save_json(input_data, os.path.join(peptideb_path, 'input.json'))
 
-        cmd = [TC1_EXECUTABLE_PATH, '-j', peptidea_input_path, '--split', '--split-dir=%s' % os.path.join( peptidea_path,'parameter_units'), '--keep-empty-row']
+        cmd = [executable_path, '-j', peptidea_input_path, '--split', '--split-dir=%s' % os.path.join( peptidea_path,'parameter_units'), '--keep-empty-row']
         logging.debug(' '.join(cmd))
         process = Popen(cmd, stdout=PIPE)
-        cmd = [TC1_EXECUTABLE_PATH, '-j', peptideb_input_path, '--split', '--split-dir=%s' % os.path.join( peptideb_path,'parameter_units'), '--keep-empty-row']
+        cmd = [executable_path, '-j', peptideb_input_path, '--split', '--split-dir=%s' % os.path.join( peptideb_path,'parameter_units'), '--keep-empty-row']
         logging.debug(' '.join(cmd))
         process = Popen(cmd, stdout=PIPE)
         stdoutdata, stderrdata_ignored = process.communicate()
